Module blob_route

Module blob_route 

One-hop blob routing values and their compact process/network wire codec.

Structs

BlobRequest
BlobRouteContext
Per-search limits supplied by an outer router to one opaque route.
StoreBlobRoute
A terminal route that performs exactly one lookup and does not interpret HTL.

Enums

BlobCodecError
BlobReply
BlobReplyHeader

Constants

BLOB_DEFAULT_HTL
Default Hashtree mesh-search budget used by standalone resolvers.
BLOB_MAX_BYTES
BLOB_MAX_HTL
Maximum number of Hashtree mesh forwarding hops accepted by the protocol.
BLOB_REPLY_HEADER_BYTES
BLOB_REQUEST_BYTES

Traits

BlobRoute

Functions

decode_blob_reply_header
decode_blob_request
encode_blob_reply_header
encode_blob_request