try_decode_tree_node

Function try_decode_tree_node 

pub fn try_decode_tree_node(data: &[u8]) -> Option<TreeNode>
Try to decode data as a tree node Returns Some(TreeNode) if valid tree node, None otherwise This is preferred over is_tree_node() to avoid double decoding