pub fn decode(code: &str) -> Result<DecodeResult, NHashError>Expand description
Decode an nhash string, returning a tagged decode result.
pub fn decode(code: &str) -> Result<DecodeResult, NHashError>Decode an nhash string, returning a tagged decode result.