pub async fn verify_tree<S: Store>(
store: Arc<S>,
root_hash: &Hash,
) -> Result<VerifyResult, ReaderError>Expand description
Verify tree integrity Checks that all referenced hashes exist
pub async fn verify_tree<S: Store>(
store: Arc<S>,
root_hash: &Hash,
) -> Result<VerifyResult, ReaderError>Verify tree integrity Checks that all referenced hashes exist